(* TEST
 ocamldoc with html;
*)

open String

(** This is a documentation comment for [x], not a module preamble. *)
val x: unit
